# User Guide

The lakeFS-spec user guide provides documentation for users of the library looking to solve specific tasks.
See the [Quickstart guide](../quickstart.md) for an introductory tutorial.

- [How to use the lakeFS file system](filesystem-usage.md)
- [Passing configuration to the file system](configuration.md)
- [Using file system transactions](transactions.md)
- [Using transactions on the lakeFS file system](transactions.md)
- [How to use lakeFS-spec with third-party data science libraries](integrations.md)
